import CryptoJS from "crypto-js";
import Utf8 from "crypto-js/enc-utf8";
import AES from "crypto-js/aes";
import Pkcs7 from "crypto-js/pad-pkcs7";

export class AESCipher {
  key: CryptoJS.lib.WordArray;
  //@ts-ignore
  mode: BlockCipherMode;
  //@ts-ignore
  padding: Padding;
  constructor(key: string, mode = CryptoJS.mode.ECB, padding = Pkcs7) {
    this.key = Utf8.parse(key);
    this.mode = mode;
    this.padding = padding;
  }

  // 加密函数
  encrypt(plaintext: string | CryptoJS.lib.WordArray) {
    const encrypted = AES.encrypt(plaintext, this.key, {
      mode: this.mode,
      padding: this.padding,
    }).toString();
    return encrypted;
  }

  // 解密函数（可选）
  decrypt(encryptedText: string | CryptoJS.lib.CipherParams) {
    const decrypted = AES.decrypt(encryptedText, this.key, {
      mode: this.mode,
      padding: this.padding,
    }).toString(Utf8);
    return decrypted;
  }
}

const defaultKey = 'quarkfeAse123'
export const aesCipher = new AESCipher(defaultKey)

/**
 * 返回加密后的数据
 * @param data {any} 接口返回的数据
 * @param shouldEncrypt {boolean} 是否加密
 * @returns {string}
 */

export const encyptedResponse = (data: any, shouldEncrypt: boolean = false) => {
  return shouldEncrypt ? aesCipher.encrypt(data) : data
};

/**
 * 返回解密后的数据
 * @param data {any} 接口返回的数据
 * @param shouldEncrypt {boolean} 是否加密
 * @returns {string}
 */

export const decryptResponse = (data: any, shouldEncrypt: boolean = false) => {
  if(shouldEncrypt && typeof data === 'string') {
    return JSON.parse(aesCipher.decrypt(data))
  }
  return data
}